===========
Expressions
===========

This page gives an overview of all public Polars expressions.

.. toctree::
   :maxdepth: 2
   :hidden:

   aggregation
   array
   binary
   boolean
   categories
   columns
   computation
   functions
   list
   modify_select
   meta
   miscellaneous
   name
   operators
   string
   struct
   temporal
   window

.. currentmodule:: polars

.. autoclass:: Expr
    :members:
    :noindex:
    :autosummary:
    :autosummary-nosignatures:
